@@ -23,12 +23,11 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
@@ -37,6 +36,6 @@ package org.gradle.kotlin.dsl
  *
  * @see org.gradle.api.plugins.PluginAware.apply
  */
-inline fun org.gradle.api.plugins.PluginAware.`apply`(vararg `options`: Pair<String, Any?>): Unit =
+inline fun org.gradle.api.plugins.PluginAware.`apply`(vararg `options`: Pair<String, Any>): Unit =
     `apply`(mapOf(*`options`))
 
