@@ -23,13 +23,12 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 @file:org.gradle.api.Incubating
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
