@@ -23,12 +23,11 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
@@ -37,6 +36,6 @@ package org.gradle.kotlin.dsl
  *
  * @see org.gradle.plugins.ide.eclipse.model.EclipseWtpFacet.facet
  */
-inline fun org.gradle.plugins.ide.eclipse.model.EclipseWtpFacet.`facet`(vararg `args`: Pair<String, Any?>): Unit =
+inline fun org.gradle.plugins.ide.eclipse.model.EclipseWtpFacet.`facet`(vararg `args`: Pair<String, Any>): Unit =
     `facet`(mapOf(*`args`))
 
